function v=compute_inflow_surge_bx(vmax,rmax,r35,vt,phi,phi_in,w,a,n,lat)
% Computes inflow surge x shift
% Script automatically generated by fit_inflow_surge_bx.m
% Inputs : 
% vmax           = Vmax (km/h)
% rmax           = Rmax (km)
% r35            = R35 (km)
% vt             = forward speed (km/h)
% phi            = track angle (deg)
% phi_in         = inflow angle (deg)
% w              = shelf width (km)
% a              = Dean slope a (-)
% n              = Mannings n
% lat            = latitude (deg)

% R2    = 0.51791
% RMSE  = 8.3436
% MEAN  = -9.0916
% RANGE = -33.4921 - 14.6021

beta( 1 )= -1.1447e+01 ;
beta( 2 )= -1.7139e-03 ;
beta( 3 )= -4.7020e+01 ;
beta( 4 )= 1.6284e+00 ;
beta( 5 )= -2.7009e-01 ;
beta( 6 )= 2.3646e+02 ;
beta( 7 )= 3.3828e-01 ;

v=beta(1)+beta(2).*sin((phi-beta(3))*pi/180).*r35.^beta(4) + beta(5)*phi_in + beta(6)*a + beta(7)*vt;
